Frequently Asked Questions
--------------------------

Do you accept template contributions?
'''''''''''''''''''''''''''''''''''''

Yes, if they are somewhat general.  And, it is a great way to have me maintain
template compatibility for you in case something changes in a future version.

Either open an issue_ or push them to a fork on GitHub_.

.. _issue: https://github.com/JNRowe/hubugs/issues
.. _GitHub: https://github.com/JNRowe/hubugs/

I don't like your choice of template language
'''''''''''''''''''''''''''''''''''''''''''''

[It isn't really a question, but it has come up a couple of times.]

The use of Jinja_ should only be an issue if you wish to author your own
templates, if you're using the built-in templates you shouldn't notice Jinja_ at
all.  That said...

The use of Jinja_ seems to be an entry barrier to some people, but it isn't
going to change.  For the same -- invariably pointless and religious -- reasons
people prefer other templating engines *I* prefer Jinja_.

.. note::
   With all that said, I probably wouldn't be opposed to accepting patches
   supporting additional *optional* engines ;)

.. _Jinja: http://jinja.pocoo.org/
